import request from '@/utils/request'

export function step_list(query) {
  return request({
    url: '/system/business/step/list',
    method: 'get',
    params: query
  })
}

export function step_info(query) {
  return request({
    url: '/system/business/step/info',
    method: 'get',
    params: query
  })
}

export function step_save(data) {
  return request({
    url: '/system/business/step/save',
    method: 'post',
    data: data
  })
}

export function step_delete(data) {
  return request({
    url: '/system/business/step/delete',
    method: 'post',
    data: data
  })
}

export function stepGroup_list(query) {
  return request({
    url: '/system/business/stepGroup/list',
    method: 'get',
    params: query
  })
}

export function stepGroup_info(query) {
  return request({
    url: '/system/business/stepGroup/info',
    method: 'get',
    params: query
  })
}

export function stepGroup_save(data) {
  return request({
    url: '/system/business/stepGroup/save',
    method: 'post',
    data: data
  })
}

export function stepGroup_delete(data) {
  return request({
    url: '/system/business/stepGroup/delete',
    method: 'post',
    data: data
  })
}
